@@ -422,7 +422,7 @@ class LimitOffset(PaginationFilter):
             :class:`sqlalchemy.sql.expression.Select`: SQLAlchemy SELECT statement
         """
         if isinstance(statement, Select):
-            return cast("StatementTypeT", statement.limit(self.limit).offset(self.offset))
+            return statement.limit(self.limit).offset(self.offset)
         return statement
 
 
@@ -468,8 +468,8 @@ class OrderBy(StatementFilter):
             return statement
         field = self._get_instrumented_attr(model, self.field_name)
         if self.sort_order == "desc":
-            return cast("StatementTypeT", statement.order_by(field.desc()))
-        return cast("StatementTypeT", statement.order_by(field.asc()))
+            return statement.order_by(field.desc())
+        return statement.order_by(field.asc())
 
 
 @dataclass
@@ -567,7 +567,10 @@ class SearchFilter(StatementFilter):
         See Also:
             :meth:`sqlalchemy.sql.expression.Select.where`: SQLAlchemy WHERE clause
         """
-        where_clause = self._operator(*self.get_search_clauses(model))
+        search_clauses = self.get_search_clauses(model)
+        if not search_clauses:
+            return statement
+        where_clause = self._operator(*search_clauses)
         return cast("StatementTypeT", statement.where(where_clause))
 
 
