@@ -1,5 +1,5 @@
 from advanced_alchemy.mixins.audit import AuditColumns
-from advanced_alchemy.mixins.bigint import BigIntPrimaryKey
+from advanced_alchemy.mixins.bigint import BigIntPrimaryKey, IdentityPrimaryKey
 from advanced_alchemy.mixins.nanoid import NanoIDPrimaryKey
 from advanced_alchemy.mixins.sentinel import SentinelMixin
 from advanced_alchemy.mixins.slug import SlugKey
@@ -9,6 +9,7 @@ from advanced_alchemy.mixins.uuid import UUIDPrimaryKey, UUIDv6PrimaryKey, UUIDv
 __all__ = (
     "AuditColumns",
     "BigIntPrimaryKey",
+    "IdentityPrimaryKey",
     "NanoIDPrimaryKey",
     "SentinelMixin",
     "SlugKey",
