@@ -97,9 +97,9 @@ def model_from_dict(model: type[ModelT], **kwargs: Any) -> ModelT:
         ModelT: A new instance of the model populated with the provided values.
     """
     data = {
-        column_name: kwargs[column_name]
-        for column_name in model.__mapper__.columns.keys()  # noqa: SIM118  # pyright: ignore[reportUnknownMemberType]
-        if column_name in kwargs
+        attr_name: kwargs[attr_name]
+        for attr_name in model.__mapper__.attrs.keys()  # noqa: SIM118  # pyright: ignore[reportUnknownMemberType]
+        if attr_name in kwargs
     }
     return model(**data)
 
@@ -338,4 +338,27 @@ class FilterableRepository(FilterableRepositoryProtocol[ModelT]):
         """
         if not isinstance(statement, Select):
             return statement
-        return cast("StatementTypeT", statement.order_by(field.desc() if is_desc else field.asc()))
+        return statement.order_by(field.desc() if is_desc else field.asc())
+
+
+def column_has_defaults(column: Any) -> bool:
+    """Check if a column has any type of default value or update handler.
+
+    This includes:
+    - Python-side defaults (column.default)
+    - Server-side defaults (column.server_default)
+    - Python-side onupdate handlers (column.onupdate)
+    - Server-side onupdate handlers (column.server_onupdate)
+
+    Args:
+        column: SQLAlchemy column object to check
+
+    Returns:
+        bool: True if the column has any type of default or update handler
+    """
+    return (
+        column.default is not None
+        or column.server_default is not None
+        or column.onupdate is not None
+        or column.server_onupdate is not None
+    )
