@@ -257,7 +257,7 @@ class Base(DeclarativeBase):
     pass
 
 class User(Base):
-    __tablename__ = "user"
+    __tablename__ = "user_table"
     id: Mapped[int] = mapped_column(primary_key=True)
     kw: Mapped[List[Keyword]] = relationship(secondary=lambda: user_keyword_table, info=dto_field("private"))
     # proxy the 'keyword' attribute from the 'kw' relationship
@@ -271,7 +271,7 @@ class Keyword(Base):
 user_keyword_table: Final[Table] = Table(
     "user_keyword",
     Base.metadata,
-    Column("user_id", Integer, ForeignKey("user.id"), primary_key=True),
+    Column("user_id", Integer, ForeignKey("user_table.id"), primary_key=True),
     Column("keyword_id", Integer, ForeignKey("keyword.id"), primary_key=True),
 )
 
