@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 import datetime
+import decimal
 from collections.abc import AsyncGenerator, Collection, Generator
 from typing import TYPE_CHECKING, Any, Union, cast
 from unittest.mock import AsyncMock, MagicMock
@@ -12,10 +13,11 @@ import pytest
 from msgspec import Struct
 from pydantic import BaseModel
 from pytest_lazy_fixtures import lf
-from sqlalchemy import String
+from sqlalchemy import Integer, String
 from sqlalchemy.exc import SQLAlchemyError
 from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy.orm import InstrumentedAttribute, Mapped, Session, mapped_column
+from sqlalchemy.types import TypeEngine
 
 from advanced_alchemy import base
 from advanced_alchemy.exceptions import IntegrityError, RepositoryError, wrap_sqlalchemy_exception
@@ -30,6 +32,7 @@ from advanced_alchemy.repository import (
     SQLAlchemyAsyncRepository,
     SQLAlchemySyncRepository,
 )
+from advanced_alchemy.repository._util import column_has_defaults, model_from_dict
 from advanced_alchemy.service.typing import (
     is_msgspec_struct,
     is_pydantic_model,
@@ -756,19 +759,20 @@ async def test_sqlalchemy_repo_update(
     """Test the sequence of repo calls for update operation."""
     id_ = 3
     mock_instance = MagicMock()
+    existing_instance = MagicMock()
     mocker.patch.object(mock_repo, "get_id_attribute_value", return_value=id_)
-    mocker.patch.object(mock_repo, "get")
-    mock_repo.session.merge.return_value = mock_instance  # pyright: ignore[reportFunctionMemberAccess]
+    mocker.patch.object(mock_repo, "get", return_value=existing_instance)
+    mock_repo.session.merge.return_value = existing_instance  # pyright: ignore[reportFunctionMemberAccess]
 
     instance = await maybe_async(mock_repo.update(mock_instance))
 
-    assert instance is mock_instance
-    mock_repo.session.merge.assert_called_once_with(mock_instance, load=True)  # pyright: ignore[reportFunctionMemberAccess]
+    assert instance is existing_instance
+    mock_repo.session.merge.assert_called_once_with(existing_instance, load=True)  # pyright: ignore[reportFunctionMemberAccess]
     mock_repo.session.flush.assert_called_once()  # pyright: ignore[reportFunctionMemberAccess]
     mock_repo.session.expunge.assert_not_called()  # pyright: ignore[reportFunctionMemberAccess]
     mock_repo.session.commit.assert_not_called()  # pyright: ignore[reportFunctionMemberAccess]
     mock_repo.session.refresh.assert_called_once_with(  # pyright: ignore[reportFunctionMemberAccess]
-        instance=mock_instance,
+        instance=existing_instance,
         attribute_names=None,
         with_for_update=None,
     )
@@ -846,6 +850,174 @@ async def test_filter_on_datetime_field(
     mock_repo.statement.where.assert_not_called()  # pyright: ignore[reportFunctionMemberAccess]
 
 
+# Type compatibility test fixtures and classes
+class MockComplexType:
+    """Mock complex type that would have DBAPI serialization issues."""
+
+    def __init__(self, value: Any):
+        self.value = value
+
+
+class MockPostgreSQLRange:
+    """Mock PostgreSQL Range type."""
+
+    def __init__(self, lower: Any, upper: Any):
+        self.lower = lower
+        self.upper = upper
+
+
+class MockTypeWithoutPythonType(TypeEngine[Any]):
+    """Mock SQLAlchemy type that doesn't implement python_type."""
+
+    def __init__(self) -> None:
+        super().__init__()
+
+    @property
+    def python_type(self) -> type[Any]:
+        raise NotImplementedError("This type doesn't have a python_type")
+
+
+async def test_type_must_use_in_empty_list(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test that empty list returns False."""
+    result = mock_repo._type_must_use_in_instead_of_any([])
+    assert result is False
+
+
+async def test_type_must_use_in_standard_python_types(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test that standard Python types can use ANY() operator."""
+    # Test integers
+    result = mock_repo._type_must_use_in_instead_of_any([1, 2, 3])
+    assert result is False
+
+    # Test strings
+    result = mock_repo._type_must_use_in_instead_of_any(["a", "b", "c"])
+    assert result is False
+
+    # Test booleans
+    result = mock_repo._type_must_use_in_instead_of_any([True, False])
+    assert result is False
+
+    # Test floats
+    result = mock_repo._type_must_use_in_instead_of_any([1.1, 2.2])
+    assert result is False
+
+    # Test bytes
+    result = mock_repo._type_must_use_in_instead_of_any([b"test", b"data"])
+    assert result is False
+
+
+async def test_type_must_use_in_safe_datetime_decimal_types(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test that datetime and decimal types can use ANY() operator."""
+    # Test datetime.date
+    result = mock_repo._type_must_use_in_instead_of_any([datetime.date(2024, 1, 1)])
+    assert result is False
+
+    # Test datetime.datetime
+    result = mock_repo._type_must_use_in_instead_of_any([datetime.datetime.now()])
+    assert result is False
+
+    # Test datetime.time
+    result = mock_repo._type_must_use_in_instead_of_any([datetime.time(12, 30)])
+    assert result is False
+
+    # Test datetime.timedelta
+    result = mock_repo._type_must_use_in_instead_of_any([datetime.timedelta(days=1)])
+    assert result is False
+
+    # Test decimal.Decimal
+    result = mock_repo._type_must_use_in_instead_of_any([decimal.Decimal("10.5")])
+    assert result is False
+
+
+async def test_type_must_use_in_complex_types(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test that complex types must use IN() operator."""
+    # Test mock PostgreSQL Range
+    ranges = [MockPostgreSQLRange(1, 10), MockPostgreSQLRange(20, 30)]
+    result = mock_repo._type_must_use_in_instead_of_any(ranges)
+    assert result is True
+
+    # Test custom complex type
+    complex_types = [MockComplexType("test")]
+    result = mock_repo._type_must_use_in_instead_of_any(complex_types)
+    assert result is True
+
+
+async def test_type_must_use_in_mixed_types_with_complex(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test that mixed types containing complex types use IN() operator."""
+    mixed_values = [1, "test", MockComplexType("complex")]
+    result = mock_repo._type_must_use_in_instead_of_any(mixed_values)
+    assert result is True
+
+
+async def test_type_must_use_in_none_values_ignored(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test that None values are properly ignored."""
+    values_with_none = [1, None, 3]
+    result = mock_repo._type_must_use_in_instead_of_any(values_with_none)
+    assert result is False
+
+    # Test only None values
+    only_none = [None, None]
+    result = mock_repo._type_must_use_in_instead_of_any(only_none)
+    assert result is False
+
+
+async def test_type_must_use_in_sqlalchemy_type_matching(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test SQLAlchemy type introspection with matching types."""
+    # Test Integer type with integer values
+    int_type = Integer()
+    result = mock_repo._type_must_use_in_instead_of_any([1, 2, 3], int_type)
+    assert result is False
+
+    # Test String type with string values
+    str_type = String()
+    result = mock_repo._type_must_use_in_instead_of_any(["a", "b"], str_type)
+    assert result is False
+
+
+async def test_type_must_use_in_sqlalchemy_type_mismatched(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test SQLAlchemy type introspection with mismatched types."""
+    # Test Integer type with string values (mismatch)
+    int_type = Integer()
+    result = mock_repo._type_must_use_in_instead_of_any(["not_an_int"], int_type)
+    assert result is True
+
+    # Test String type with integer values (mismatch)
+    str_type = String()
+    result = mock_repo._type_must_use_in_instead_of_any([123], str_type)
+    assert result is True
+
+
+async def test_type_must_use_in_sqlalchemy_type_without_python_type(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test SQLAlchemy type that doesn't implement python_type."""
+    mock_type: MockTypeWithoutPythonType = MockTypeWithoutPythonType()
+    result = mock_repo._type_must_use_in_instead_of_any([1, 2, 3], mock_type)
+    assert result is True  # Should use IN() for safety
+
+
+async def test_type_must_use_in_sqlalchemy_type_with_none_python_type(
+    mock_repo: SQLAlchemyAsyncRepository[Any],
+) -> None:
+    """Test SQLAlchemy type that has None as python_type."""
+    mock_type = MagicMock()
+    mock_type.python_type = None
+
+    # Should fall back to Python type checking
+    result = mock_repo._type_must_use_in_instead_of_any([1, 2, 3], mock_type)
+    assert result is False  # Standard integers should use ANY()
+
+    result = mock_repo._type_must_use_in_instead_of_any([MockComplexType("test")], mock_type)
+    assert result is True  # Complex types should use IN()
+
+
+async def test_type_must_use_in_missing_python_type_attribute(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test fallback when python_type attribute is missing from type."""
+    # Create a mock that doesn't have python_type attribute at all
+    mock_type = type("MockType", (), {})()  # Empty object with no attributes
+
+    result = mock_repo._type_must_use_in_instead_of_any([1, 2, 3], mock_type)
+    assert result is False  # Should fall back to Python type checking for safe types
+
+
 class MyModel(BaseModel):
     name: str
     age: int
@@ -906,3 +1078,481 @@ def test_is_schema_or_dict() -> None:
     assert not is_schema_or_dict_with_field(msgspec_struct, "name2")
     assert is_schema_or_dict_without_field(pydantic_model, "name2")
     assert not is_schema_or_dict_without_field(msgspec_struct, "name")
+
+
+# Tests for new methods added in id-attribute-update branch
+
+
+def test_async_type_must_use_in_empty_values(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test that empty values return False."""
+    assert mock_repo._type_must_use_in_instead_of_any([]) is False
+
+
+def test_sync_type_must_use_in_empty_values(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test that empty values return False."""
+    assert sync_mock_repo._type_must_use_in_instead_of_any([]) is False
+
+
+def test_async_safe_types_with_field_type(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test safe types with valid field type."""
+    # Mock field type with python_type
+    mock_field_type = MagicMock()
+    mock_field_type.python_type = str
+
+    values = ["test", "another_string"]
+    result = mock_repo._type_must_use_in_instead_of_any(values, mock_field_type)
+    assert result is False
+
+
+def test_sync_type_mismatch_with_field_type(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test type mismatch triggers IN() usage."""
+    # Mock field type expecting strings
+    mock_field_type = MagicMock()
+    mock_field_type.python_type = str
+
+    # Pass integers when expecting strings
+    values = [1, 2, 3]
+    result = sync_mock_repo._type_must_use_in_instead_of_any(values, mock_field_type)
+    assert result is True
+
+
+def test_async_field_type_none_python_type(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test behavior when field_type.python_type is None."""
+    mock_field_type = MagicMock()
+    mock_field_type.python_type = None
+
+    values = [{"complex": "object"}]  # Non-safe type
+    result = mock_repo._type_must_use_in_instead_of_any(values, mock_field_type)
+    assert result is True  # Should use fallback logic
+
+
+def test_sync_field_type_no_python_type_attr(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test behavior when field_type has no python_type attribute."""
+    # Create object without python_type attribute
+    mock_field_type = object()
+
+    values = [{"complex": "object"}]  # Non-safe type
+    result = sync_mock_repo._type_must_use_in_instead_of_any(values, mock_field_type)
+    assert result is True  # Should use fallback logic for non-safe types
+
+
+def test_async_no_field_type_safe_values(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test safe values without field type information."""
+    # Test all safe types
+    safe_values = [
+        42,
+        3.14,
+        "string",
+        True,
+        b"bytes",
+        decimal.Decimal("10.5"),
+        datetime.date.today(),
+        datetime.datetime.now(),
+        datetime.time(12, 30),
+        datetime.timedelta(days=1),
+    ]
+
+    result = mock_repo._type_must_use_in_instead_of_any(safe_values)
+    assert result is False
+
+
+def test_sync_no_field_type_unsafe_values(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test unsafe values without field type information."""
+    # Test unsafe types (complex objects)
+    unsafe_values = [{"key": "value"}, [1, 2, 3], {"nested": {"data": True}}]
+
+    result = sync_mock_repo._type_must_use_in_instead_of_any(unsafe_values)
+    assert result is True
+
+
+def test_async_mixed_safe_unsafe_values(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test mixed safe and unsafe values."""
+    # Mix safe and unsafe types
+    mixed_values = ["string", 42, {"unsafe": "dict"}]
+
+    result = mock_repo._type_must_use_in_instead_of_any(mixed_values)
+    assert result is True
+
+
+def test_sync_none_values_handling(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test handling of None values."""
+    # None values should be ignored in type checking
+    values_with_none = [None, "string", None, 42]
+
+    result = sync_mock_repo._type_must_use_in_instead_of_any(values_with_none)
+    assert result is False
+
+
+def test_async_empty_values(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test empty list returns empty list."""
+    result = mock_repo._get_unique_values([])
+    assert result == []
+
+
+def test_sync_hashable_values(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test hashable values deduplication."""
+    values = [1, 2, 1, 3, 2, 4]
+    result = sync_mock_repo._get_unique_values(values)
+    assert result == [1, 2, 3, 4]
+
+
+def test_async_string_values(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test string deduplication."""
+    values = ["a", "b", "a", "c", "b"]
+    result = mock_repo._get_unique_values(values)
+    assert result == ["a", "b", "c"]
+
+
+def test_sync_unhashable_values(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test unhashable values (dicts) deduplication."""
+    values = [
+        {"key": "value1"},
+        {"key": "value2"},
+        {"key": "value1"},  # duplicate
+        {"key": "value3"},
+    ]
+    result = sync_mock_repo._get_unique_values(values)
+    expected = [{"key": "value1"}, {"key": "value2"}, {"key": "value3"}]
+    assert result == expected
+
+
+def test_async_mixed_types(mock_repo: SQLAlchemyAsyncRepository[Any]) -> None:
+    """Test mixed hashable and unhashable types."""
+    # Mix strings and dicts to trigger TypeError in set operations
+    values = ["string", {"dict": "value"}, "string", {"other": "dict"}]
+    result = mock_repo._get_unique_values(values)
+    expected = ["string", {"dict": "value"}, {"other": "dict"}]
+    assert result == expected
+
+
+def test_sync_preserves_order(sync_mock_repo: SQLAlchemySyncRepository[Any]) -> None:
+    """Test that order is preserved in deduplication."""
+    values = [3, 1, 4, 1, 5, 9, 2, 6, 5, 3]
+    result = sync_mock_repo._get_unique_values(values)
+    assert result == [3, 1, 4, 5, 9, 2, 6]
+
+
+def test_column_with_python_default() -> None:
+    """Test column with Python-side default."""
+    mock_column = MagicMock()
+    mock_column.default = "default_value"
+    mock_column.server_default = None
+    mock_column.onupdate = None
+    mock_column.server_onupdate = None
+
+    assert column_has_defaults(mock_column) is True
+
+
+def test_column_with_server_default() -> None:
+    """Test column with server-side default."""
+    mock_column = MagicMock()
+    mock_column.default = None
+    mock_column.server_default = "DEFAULT VALUE"
+    mock_column.onupdate = None
+    mock_column.server_onupdate = None
+
+    assert column_has_defaults(mock_column) is True
+
+
+def test_column_with_python_onupdate() -> None:
+    """Test column with Python-side onupdate."""
+    mock_column = MagicMock()
+    mock_column.default = None
+    mock_column.server_default = None
+    mock_column.onupdate = "update_function"
+    mock_column.server_onupdate = None
+
+    assert column_has_defaults(mock_column) is True
+
+
+def test_column_with_server_onupdate() -> None:
+    """Test column with server-side onupdate."""
+    mock_column = MagicMock()
+    mock_column.default = None
+    mock_column.server_default = None
+    mock_column.onupdate = None
+    mock_column.server_onupdate = "UPDATE_FUNCTION"
+
+    assert column_has_defaults(mock_column) is True
+
+
+def test_column_with_no_defaults() -> None:
+    """Test column with no defaults."""
+    mock_column = MagicMock()
+    mock_column.default = None
+    mock_column.server_default = None
+    mock_column.onupdate = None
+    mock_column.server_onupdate = None
+
+    assert column_has_defaults(mock_column) is False
+
+
+def test_column_with_false_default() -> None:
+    """Test column where default is False (falsy but not None)."""
+    mock_column = MagicMock()
+    mock_column.default = False  # Falsy but not None
+    mock_column.server_default = None
+    mock_column.onupdate = None
+    mock_column.server_onupdate = None
+
+    assert column_has_defaults(mock_column) is True
+
+
+def test_column_with_zero_default() -> None:
+    """Test column where default is 0 (falsy but not None)."""
+    mock_column = MagicMock()
+    mock_column.default = 0  # Falsy but not None
+    mock_column.server_default = None
+    mock_column.onupdate = None
+    mock_column.server_onupdate = None
+
+    assert column_has_defaults(mock_column) is True
+
+
+def test_column_with_empty_string_default() -> None:
+    """Test column where default is empty string (falsy but not None)."""
+    mock_column = MagicMock()
+    mock_column.default = ""  # Falsy but not None
+    mock_column.server_default = None
+    mock_column.onupdate = None
+    mock_column.server_onupdate = None
+
+    assert column_has_defaults(mock_column) is True
+
+
+def test_model_from_dict_includes_relationship_attributes() -> None:
+    """Test that model_from_dict includes relationship attributes from __mapper__.attrs.keys()."""
+    from tests.fixtures.uuid.models import UUIDAuthor
+
+    # Verify that attrs.keys() includes relationships while columns.keys() doesn't
+    columns_keys = list(UUIDAuthor.__mapper__.columns.keys())
+    attrs_keys = list(UUIDAuthor.__mapper__.attrs.keys())
+
+    assert "books" not in columns_keys, "books relationship should NOT be in columns.keys()"
+    assert "books" in attrs_keys, "books relationship should be in attrs.keys()"
+
+
+# Tests for write_only relationship handling in update method (issue #524)
+
+
+async def test_update_skips_write_only_relationships(
+    mock_repo: SQLAlchemyAsyncRepository[Any],
+    mocker: MockerFixture,
+) -> None:
+    """Test that update method skips write_only relationships without error."""
+    id_ = 3
+    mock_instance = MagicMock()
+    existing_instance = MagicMock()
+
+    # Mock the mapper and relationship
+    mock_mapper = MagicMock()
+    mock_relationship = MagicMock()
+    mock_relationship.key = "items"
+    mock_relationship.lazy = "write_only"
+    mock_relationship.viewonly = False
+    mock_mapper.mapper.columns = []
+    mock_mapper.mapper.relationships = [mock_relationship]
+
+    # Mock the data object to have the write_only relationship attribute
+    mock_instance.items = MagicMock()  # This would be a WriteOnlyCollection in reality
+
+    mocker.patch.object(mock_repo, "get_id_attribute_value", return_value=id_)
+    mocker.patch.object(mock_repo, "get", return_value=existing_instance)
+    mocker.patch("advanced_alchemy.repository._async.inspect", return_value=mock_mapper)
+    mock_repo.session.merge.return_value = existing_instance  # pyright: ignore[reportFunctionMemberAccess]
+
+    # This should not raise an error even though items is a write_only relationship
+    instance = await maybe_async(mock_repo.update(mock_instance))
+
+    # Verify the relationship was not processed (no merge attempted for relationships)
+    mock_repo.session.merge.assert_called_once_with(existing_instance, load=True)  # pyright: ignore[reportFunctionMemberAccess]
+    assert instance is existing_instance
+
+
+async def test_update_skips_dynamic_relationships(
+    mock_repo: SQLAlchemyAsyncRepository[Any],
+    mocker: MockerFixture,
+) -> None:
+    """Test that update method skips dynamic relationships without error."""
+    id_ = 3
+    mock_instance = MagicMock()
+    existing_instance = MagicMock()
+
+    # Mock the mapper and relationship
+    mock_mapper = MagicMock()
+    mock_relationship = MagicMock()
+    mock_relationship.key = "items"
+    mock_relationship.lazy = "dynamic"
+    mock_relationship.viewonly = False
+    mock_mapper.mapper.columns = []
+    mock_mapper.mapper.relationships = [mock_relationship]
+
+    # Mock the data object to have the dynamic relationship attribute
+    mock_instance.items = MagicMock()  # This would be an AppenderQuery in reality
+
+    mocker.patch.object(mock_repo, "get_id_attribute_value", return_value=id_)
+    mocker.patch.object(mock_repo, "get", return_value=existing_instance)
+    mocker.patch("advanced_alchemy.repository._async.inspect", return_value=mock_mapper)
+    mock_repo.session.merge.return_value = existing_instance  # pyright: ignore[reportFunctionMemberAccess]
+
+    # This should not raise an error even though items is a dynamic relationship
+    instance = await maybe_async(mock_repo.update(mock_instance))
+
+    # Verify the relationship was not processed (no merge attempted for relationships)
+    mock_repo.session.merge.assert_called_once_with(existing_instance, load=True)  # pyright: ignore[reportFunctionMemberAccess]
+    assert instance is existing_instance
+
+
+async def test_update_skips_viewonly_relationships(
+    mock_repo: SQLAlchemyAsyncRepository[Any],
+    mocker: MockerFixture,
+) -> None:
+    """Test that update method skips viewonly relationships without error."""
+    id_ = 3
+    mock_instance = MagicMock()
+    existing_instance = MagicMock()
+
+    # Mock the mapper and relationship
+    mock_mapper = MagicMock()
+    mock_relationship = MagicMock()
+    mock_relationship.key = "readonly_items"
+    mock_relationship.lazy = "select"  # Normal lazy loading
+    mock_relationship.viewonly = True  # But marked as view-only
+    mock_mapper.mapper.columns = []
+    mock_mapper.mapper.relationships = [mock_relationship]
+
+    # Mock the data object to have the viewonly relationship attribute
+    mock_instance.readonly_items = [MagicMock()]
+
+    mocker.patch.object(mock_repo, "get_id_attribute_value", return_value=id_)
+    mocker.patch.object(mock_repo, "get", return_value=existing_instance)
+    mocker.patch("advanced_alchemy.repository._async.inspect", return_value=mock_mapper)
+    mock_repo.session.merge.return_value = existing_instance  # pyright: ignore[reportFunctionMemberAccess]
+
+    # This should not raise an error even though readonly_items is viewonly
+    instance = await maybe_async(mock_repo.update(mock_instance))
+
+    # Verify the relationship was not processed (no merge attempted for relationships)
+    mock_repo.session.merge.assert_called_once_with(existing_instance, load=True)  # pyright: ignore[reportFunctionMemberAccess]
+    assert instance is existing_instance
+
+
+async def test_update_skips_raise_lazy_relationships(
+    mock_repo: SQLAlchemyAsyncRepository[Any],
+    mocker: MockerFixture,
+) -> None:
+    """Test that update method skips raise lazy strategy relationships without error."""
+    id_ = 3
+    mock_instance = MagicMock()
+    existing_instance = MagicMock()
+
+    # Mock the mapper and relationship
+    mock_mapper = MagicMock()
+    mock_relationship = MagicMock()
+    mock_relationship.key = "items"
+    mock_relationship.lazy = "raise"
+    mock_relationship.viewonly = False
+    mock_mapper.mapper.columns = []
+    mock_mapper.mapper.relationships = [mock_relationship]
+
+    # Mock the data object to have the raise relationship attribute
+    mock_instance.items = MagicMock()
+
+    mocker.patch.object(mock_repo, "get_id_attribute_value", return_value=id_)
+    mocker.patch.object(mock_repo, "get", return_value=existing_instance)
+    mocker.patch("advanced_alchemy.repository._async.inspect", return_value=mock_mapper)
+    mock_repo.session.merge.return_value = existing_instance  # pyright: ignore[reportFunctionMemberAccess]
+
+    # This should not raise an error even though items has lazy="raise"
+    instance = await maybe_async(mock_repo.update(mock_instance))
+
+    # Verify the relationship was not processed (no merge attempted for relationships)
+    mock_repo.session.merge.assert_called_once_with(existing_instance, load=True)  # pyright: ignore[reportFunctionMemberAccess]
+    assert instance is existing_instance
+
+
+async def test_update_processes_normal_relationships(
+    mock_repo: SQLAlchemyAsyncRepository[Any],
+    mocker: MockerFixture,
+) -> None:
+    """Test that update method still processes normal relationships correctly."""
+    id_ = 3
+    mock_instance = MagicMock()
+    existing_instance = MagicMock()
+    related_item = MagicMock()
+    merged_related_item = MagicMock()
+
+    # Mock the mapper and relationship
+    mock_mapper = MagicMock()
+    mock_relationship = MagicMock()
+    mock_relationship.key = "items"
+    mock_relationship.lazy = "select"  # Normal lazy loading
+    mock_relationship.viewonly = False
+    mock_mapper.mapper.columns = []
+    mock_mapper.mapper.relationships = [mock_relationship]
+
+    # Mock the data object to have a normal relationship with items
+    mock_instance.items = [related_item]
+
+    mocker.patch.object(mock_repo, "get_id_attribute_value", return_value=id_)
+    mocker.patch.object(mock_repo, "get", return_value=existing_instance)
+    mocker.patch("advanced_alchemy.repository._async.inspect", return_value=mock_mapper)
+
+    # Mock session.merge to return different objects for main instance vs related items
+    async def mock_merge(obj: Any, load: bool = True) -> Any:
+        if obj is existing_instance:
+            return existing_instance
+        if obj is related_item:
+            return merged_related_item
+        return obj
+
+    mock_repo.session.merge.side_effect = mock_merge
+
+    # This should process the normal relationship correctly
+    instance = await maybe_async(mock_repo.update(mock_instance))
+
+    # Verify the relationship was processed - at minimum the main instance should be merged
+    assert mock_repo.session.merge.call_count >= 1  # At least the main instance
+    # The main point is that normal relationships don't cause errors
+    assert instance is existing_instance
+
+
+def test_model_from_dict_backward_compatibility() -> None:
+    """Test that model_from_dict maintains backward compatibility with column-only data."""
+    from tests.fixtures.uuid.models import UUIDAuthor
+
+    author_data = {"name": "Compatible Author", "string_field": "compatibility test"}
+
+    author = model_from_dict(UUIDAuthor, **author_data)
+
+    assert author.name == "Compatible Author"
+    assert author.string_field == "compatibility test"
+
+
+def test_model_from_dict_ignores_unknown_attributes() -> None:
+    """Test that model_from_dict still ignores unknown attributes."""
+    from tests.fixtures.uuid.models import UUIDAuthor
+
+    author_data = {"name": "Test Author", "unknown_attribute": "should be ignored", "another_unknown": 12345}
+
+    author = model_from_dict(UUIDAuthor, **author_data)
+
+    assert author.name == "Test Author"
+    assert not hasattr(author, "unknown_attribute")
+    assert not hasattr(author, "another_unknown")
+
+
+def test_model_from_dict_empty_relationship() -> None:
+    """Test that model_from_dict handles empty relationship lists."""
+    from tests.fixtures.uuid.models import UUIDAuthor
+
+    author_data = {
+        "name": "Author Without Books",
+        "books": [],  # Empty relationship
+    }
+
+    author = model_from_dict(UUIDAuthor, **author_data)
+
+    assert author.name == "Author Without Books"
+    assert hasattr(author, "books")
+    assert author.books == []
